OiRA

Help

1. Sagatavošanās
2. Iesaiste
3. Identifikācija + Novērtēšana
   1. 1 Commercial manned guarding
   2. Ω Jūsu pievienotie riski
      1. Ω.1 The entrance floor is often wet
   - Neatbildēts
   - Atlikts jautājums
   - Viss kārtībā
   - Uzmanību
4. Rīcības plāns
5. Pārskats
6. Statuss 0%

Gadījumā, ja esat identificējis(-usi) riskus, kuri nav iekļauti rīkā, varat tos pievienot tagad:

Svarīgi: Lai izvairītos no risku atkārtošanās, mēs ļoti iesakās vispirms novērtēt visus piedāvātos riskus (ja vien Jūs to jau neesat izdarījis (usi)).

Ja jums nav jāpievieno riski, lūdzu, turpiniet.

Atpakaļ Turpināt ar pasākumu plānu

Scroll to top
Back

## other-risks.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More